==> yos.core-2.1.0-sources.jar: utility/wechat/work/receive/DefaultQYWechatMsgRecevier.java <==
package utility.wechat.work.receive;

import utility.wechat.work.receive.core.QYWechatMsgRecevier;

import java.util.HashMap;

public class DefaultQYWechatMsgRecevier extends QYWechatMsgRecevier {
    public static HashMap<String, HashMap<String, Object>> map;

    @Override
    public String switchTextMsg(String Content, String FromUserName,
                                String ToUserName) {
        return createMsg.createTextMsg(Content, FromUserName,
                ToUserName);
    }

    @Override
    public String switchClickEventMsg(String EventKey, String FromUserName,
                                      String ToUserName) {
        return createMsg.createTextMsg("您点击的按钮键值是:" + EventKey,
                FromUserName, ToUserName);
    }

    @Override
    public String switchImageMsg(String PicUrl, String MediaId,
                                 String FromUserName, String ToUserName) {
        return createMsg.createTextMsg("图片地址:" + PicUrl, FromUserName,
                ToUserName);
        /*
         * String savefile = Parameter.SaveFile.Image + FromUserName + "_" +
         * Calendar.getInstance().getTimeInMillis() + ".jpg";// 文件保存地址 DownLoad
         * downLoad = new DownLoad(MediaId, savefile); return
         * createMsg.createTextMsg("图片上传成功\n大小：" + downLoad.getfilesize() +
         * "\n网络地址：" + PicUrl, FromUserName, ToUserName);
         */
    }

    @Override
    public String switchVoiceMsg(String MediaId, String Format,
                                 String FromUserName, String ToUserName) {
        return createMsg.createTextMsg("媒体ID:" + MediaId, FromUserName,
                ToUserName);
        /*
         * String savefile = Parameter.SaveFile.Voice + FromUserName + "_" +
         * Calendar.getInstance().getTimeInMillis() + "." + Format;// 文件保存地址
         * DownLoad downLoad = new DownLoad(MediaId, savefile); return
         * createMsg.createTextMsg("音频上传成功\n格式：" + Format + "\n大小：" +
         * downLoad.getfilesize(), FromUserName, ToUserName);
         */
    }

    @Override
    public String switchVideoMsg(String MediaId, String ThumbMediaId,
                                 String FromUserName, String ToUserName) {
        return createMsg.createTextMsg("媒体ID:" + MediaId, FromUserName,
                ToUserName);
        /*
         * String savefile = Parameter.SaveFile.video + FromUserName + "_" +
         * Calendar.getInstance().getTimeInMillis() + ".rm";// 文件保存地址 DownLoad
         * downLoad = new DownLoad(MediaId, savefile); return
         * createMsg.createTextMsg("视频上传成功\n大小：" + downLoad.getfilesize(),
         * FromUserName, ToUserName);
         */
    }

    @Override
    public String switchShortvideoMsg(String MediaId, String ThumbMediaId,
                                      String FromUserName, String ToUserName) {
        return createMsg.createTextMsg("媒体ID:" + MediaId, FromUserName,
                ToUserName);
        /*
         * String savefile = Parameter.SaveFile.shortvideo + FromUserName + "_"
         * + Calendar.getInstance().getTimeInMillis() + ".rm";// 文件保存地址 DownLoad
         * downLoad = new DownLoad(MediaId, savefile);
         *
         * return createMsg.createTextMsg("小视频上传成功\n大小：" +
         * downLoad.getfilesize(), FromUserName, ToUserName);
         */
    }

    @Override
    public String switchLocationMsg(String Location_X, String Location_Y,
                                    String Scale, String Label, String FromUserName, String ToUserName) {
        return createMsg.createTextMsg("纬度：" + Location_X + "\n经度："
                + Location_Y + "\n位置描述：" + Label, FromUserName, ToUserName);
    }

    /**
     * 成员关注/取消关注事件
     */
    @Override
    public String switchSubscribeEventMsg(String AgentID, String FromUserName,
                                          String ToUserName) {
        return null;
    }

    @Override
    public String switchViewEventMsg(String EventKey, String FromUserName,
                                     String ToUserName) {
        return null;
    }

    @Override
    public String switchScancode_pushEventMsg(String EventKey, String ScanType,
                                              String ScanResult, String FromUserName, String ToUserName) {

        String strs[] = ScanResult.split(",");
        return createMsg.createTextMsg("类型：" + ScanType + "\n条码格式：" + strs[0]
                + "\n条码内容：" + strs[1], FromUserName, ToUserName);
    }

    @Override
    public String switchScancode_waitmsgEventMsg(String EventKey,
                                                 String ScanType, String ScanResult, String FromUserName,
                                                 String ToUserName) {

        if (ScanType.equals("barcode")) {
            String strs[] = ScanResult.split(",");
            return createMsg.createTextMsg("类型：" + ScanType + "\n条码格式："
                    + strs[0] + "\n条码内容：" + strs[1], FromUserName, ToUserName);
        } else {
            return createMsg.createTextMsg("类型：" + ScanType + "\n条码内容："
                    + ScanResult, FromUserName, ToUserName);
        }

    }

    @Override
    public String switchEnter_agentEventMsg(String EventKey,
                                            String FromUserName, String ToUserName) {
        return null;
        /*
         * Set<String> set = Parameter.entryDrpMap.keySet(); boolean flag =
         * true; long nowtime = System.currentTimeMillis(); if
         * (set.contains(FromUserName)) { long entrytime =
         * Parameter.entryDrpMap.get(FromUserName); if (((nowtime - entrytime) /
         * (1000 * 60)) < 5) { flag = false; } } else {
         * Parameter.entryDrpMap.put(FromUserName, nowtime); } if (flag) {
         * String a =
         * "欢迎进入嘉兴博远DRP微信客户端！当前客户端已实现查询信息反馈，文字消息、图文消息群发，DRP系统数据链接，图片、文件、视频、录音等信息的上传、位置的上传及实时记录等功能。"
         * ; return createMsg.createTextMsg("您好，欢迎光临！\n" + a, FromUserName,
         * ToUserName); } else { return null; }
         */
    }

    /**
     * 位置事件
     */
    @Override
    public String switchLocationEventMsg(String AgentID, String Latitude,
                                         String Longitude, String Precision, String FromUserName,
                                         String ToUserName) {
        return createMsg.createTextMsg("您当前所处的位置是\n纬度：" + Latitude + "\n经度："
                + Longitude, FromUserName, ToUserName);

    }
}

==> yos.core-2.5.28-sources.jar: utility/wechat/work/receive/DefaultQYWechatMsgRecevier.java <==
package utility.wechat.work.receive;

import utility.wechat.work.receive.core.QYWechatMsgRecevier;

import java.util.HashMap;

public class DefaultQYWechatMsgRecevier extends QYWechatMsgRecevier {
    public static HashMap<String, HashMap<String, Object>> map;

    @Override
    public String switchTextMsg(String AgentID, String Content, String FromUserName,
                                String ToUserName) {
        return createMsg.createTextMsg(Content, FromUserName,
                ToUserName);
    }

    @Override
    public String switchClickEventMsg(String AgentID, String EventKey, String FromUserName,
                                      String ToUserName) {
        return createMsg.createTextMsg("您点击的按钮键值是:" + EventKey,
                FromUserName, ToUserName);
    }

    @Override
    public String switchImageMsg(String AgentID, String PicUrl, String MediaId,
                                 String FromUserName, String ToUserName) {
        return createMsg.createTextMsg("图片地址:" + PicUrl, FromUserName,
                ToUserName);
        /*
         * String savefile = Parameter.SaveFile.Image + FromUserName + "_" +
         * Calendar.getInstance().getTimeInMillis() + ".jpg";// 文件保存地址 DownLoad
         * downLoad = new DownLoad(MediaId, savefile); return
         * createMsg.createTextMsg("图片上传成功\n大小：" + downLoad.getfilesize() +
         * "\n网络地址：" + PicUrl, FromUserName, ToUserName);
         */
    }

    @Override
    public String switchVoiceMsg(String AgentID, String MediaId, String Format,
                                 String FromUserName, String ToUserName) {
        return createMsg.createTextMsg("媒体ID:" + MediaId, FromUserName,
                ToUserName);
        /*
         * String savefile = Parameter.SaveFile.Voice + FromUserName + "_" +
         * Calendar.getInstance().getTimeInMillis() + "." + Format;// 文件保存地址
         * DownLoad downLoad = new DownLoad(MediaId, savefile); return
         * createMsg.createTextMsg("音频上传成功\n格式：" + Format + "\n大小：" +
         * downLoad.getfilesize(), FromUserName, ToUserName);
         */
    }

    @Override
    public String switchVideoMsg(String AgentID, String MediaId, String ThumbMediaId,
                                 String FromUserName, String ToUserName) {
        return createMsg.createTextMsg("媒体ID:" + MediaId, FromUserName,
                ToUserName);
        /*
         * String savefile = Parameter.SaveFile.video + FromUserName + "_" +
         * Calendar.getInstance().getTimeInMillis() + ".rm";// 文件保存地址 DownLoad
         * downLoad = new DownLoad(MediaId, savefile); return
         * createMsg.createTextMsg("视频上传成功\n大小：" + downLoad.getfilesize(),
         * FromUserName, ToUserName);
         */
    }

    @Override
    public String switchShortvideoMsg(String AgentID, String MediaId, String ThumbMediaId,
                                      String FromUserName, String ToUserName) {
        return createMsg.createTextMsg("媒体ID:" + MediaId, FromUserName,
                ToUserName);
        /*
         * String savefile = Parameter.SaveFile.shortvideo + FromUserName + "_"
         * + Calendar.getInstance().getTimeInMillis() + ".rm";// 文件保存地址 DownLoad
         * downLoad = new DownLoad(MediaId, savefile);
         *
         * return createMsg.createTextMsg("小视频上传成功\n大小：" +
         * downLoad.getfilesize(), FromUserName, ToUserName);
         */
    }

    @Override
    public String switchLocationMsg(String AgentID, String Location_X, String Location_Y,
                                    String Scale, String Label, String FromUserName, String ToUserName) {
        return createMsg.createTextMsg("纬度：" + Location_X + "\n经度："
                + Location_Y + "\n位置描述：" + Label, FromUserName, ToUserName);
    }

    /**
     * 成员关注/取消关注事件
     */
    @Override
    public String switchSubscribeEventMsg(String AgentID, String FromUserName,
                                          String ToUserName) {
        return null;
    }

    @Override
    public String switchViewEventMsg(String AgentID, String EventKey, String FromUserName,
                                     String ToUserName) {
        return null;
    }

    @Override
    public String switchScancode_pushEventMsg(String AgentID, String EventKey, String ScanType,
                                              String ScanResult, String FromUserName, String ToUserName) {

        String strs[] = ScanResult.split(",");
        return createMsg.createTextMsg("类型：" + ScanType + "\n条码格式：" + strs[0]
                + "\n条码内容：" + strs[1], FromUserName, ToUserName);
    }

    @Override
    public String switchScancode_waitmsgEventMsg(String AgentID, String EventKey,
                                                 String ScanType, String ScanResult, String FromUserName,
                                                 String ToUserName) {

        if (ScanType.equals("barcode")) {
            String strs[] = ScanResult.split(",");
            return createMsg.createTextMsg("类型：" + ScanType + "\n条码格式："
                    + strs[0] + "\n条码内容：" + strs[1], FromUserName, ToUserName);
        } else {
            return createMsg.createTextMsg("类型：" + ScanType + "\n条码内容："
                    + ScanResult, FromUserName, ToUserName);
        }

    }

    @Override
    public String switchEnter_agentEventMsg(String AgentID, String EventKey,
                                            String FromUserName, String ToUserName) {
        return null;
        /*
         * Set<String> set = Parameter.entryDrpMap.keySet(); boolean flag =
         * true; long nowtime = System.currentTimeMillis(); if
         * (set.contains(FromUserName)) { long entrytime =
         * Parameter.entryDrpMap.get(FromUserName); if (((nowtime - entrytime) /
         * (1000 * 60)) < 5) { flag = false; } } else {
         * Parameter.entryDrpMap.put(FromUserName, nowtime); } if (flag) {
         * String a =
         * "欢迎进入嘉兴博远DRP微信客户端！当前客户端已实现查询信息反馈，文字消息、图文消息群发，DRP系统数据链接，图片、文件、视频、录音等信息的上传、位置的上传及实时记录等功能。"
         * ; return createMsg.createTextMsg("您好，欢迎光临！\n" + a, FromUserName,
         * ToUserName); } else { return null; }
         */
    }

    /**
     * 位置事件
     */
    @Override
    public String switchLocationEventMsg(String AgentID, String Latitude,
                                         String Longitude, String Precision, String FromUserName,
                                         String ToUserName) {
        return createMsg.createTextMsg("您当前所处的位置是\n纬度：" + Latitude + "\n经度："
                + Longitude, FromUserName, ToUserName);

    }
}
